@@ -1,27 +1,41 @@
 package ZMQ::Raw::Curve;
-$ZMQ::Raw::Curve::VERSION = '0.04';
+$ZMQ::Raw::Curve::VERSION = '0.05';
 use strict;
 use warnings;
 use ZMQ::Raw;
 
 =head1 NAME
 
-ZMQ::Raw::Curve - ZeroMQ CURVE class
+ZMQ::Raw::Curve - ZeroMQ CURVE methods
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
-ZeroMQ CURVE function.
+ZeroMQ CURVE methods.
 
 =head1 SYNOPSIS
 
 	use ZMQ::Raw;
 
+	# client
 	my ($private, $public) = ZMQ::Raw::Curve->keypair();
 
+	my $req = ZMQ::Raw::Socket->new ($ctx, ZMQ::Raw->ZMQ_REQ);
+	$req->setsockopt (ZMQ::Raw::Socket->ZMQ_CURVE_SECRETKEY, $private);
+	$req->setsockopt (ZMQ::Raw::Socket->ZMQ_CURVE_PUBLICKEY, $public);
+	$req->setsockopt (ZMQ::Raw::Socket->ZMQ_CURVE_SERVERKEY, $server_public);
+
+	# server
+	my $private = ZMQ::Raw::Curve->keypair();
+
+	my $rep = ZMQ::Raw::Socket->new ($ctx, ZMQ::Raw->ZMQ_REP);
+	$rep->setsockopt (ZMQ::Raw::Socket->ZMQ_CURVE_SECRETKEY, $private);
+	$rep->setsockopt (ZMQ::Raw::Socket->ZMQ_CURVE_SERVER, 1);
+	$rep->bind ('tcp://*:5555');
+
 =head1 METHODS
 
 =head2 keypair( )
