@@ -1,5 +1,5 @@
 package ZMQ::Raw::Message;
-$ZMQ::Raw::Message::VERSION = '0.04';
+$ZMQ::Raw::Message::VERSION = '0.05';
 use strict;
 use warnings;
 use Carp;
@@ -31,12 +31,21 @@ ZMQ::Raw::Message - ZeroMQ Message class
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
 A L<ZMQ::Raw::Message> represents a ZeroMQ message.
 
+=head1 SYNOPSIS
+
+	use ZMQ::Raw;
+
+	my $msg = ZMQ::Raw::Message->new;
+	$msg->data ('hello');
+
+	$socket->sendmsg ($msg);
+
 =head1 METHODS
 
 =head2 new( )
