@@ -1,5 +1,5 @@
 package ZMQ::Raw::Socket;
-$ZMQ::Raw::Socket::VERSION = '0.04';
+$ZMQ::Raw::Socket::VERSION = '0.05';
 use strict;
 use warnings;
 use Carp;
@@ -31,7 +31,7 @@ ZMQ::Raw::Socket - ZeroMQ Socket class
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 DESCRIPTION
 
@@ -100,11 +100,13 @@ be a combination of:
 
 =item * C<ZMQ::Raw-E<gt>ZMQ_DONTWAIT>
 
-unicast transport using TCP
+Perform the operation in non-blocking mode. This method will return
+C<undef> if the message cannot be sent immediately.
 
 =item * C<ZMQ::Raw-E<gt>ZMQ_SNDMORE>
 
-local inter-process communication transport
+The message is part of a multi-part message and further message parts are to
+follow.
 
 =back
 
@@ -112,11 +114,12 @@ local inter-process communication transport
 
 Queue C<$msg> to be sent.
 
-=head2 recv( $size = 1024*1024, $flags = 0)
+=head2 recv( $flags = 0)
 
-Receive a message. If C<$size> does not have enough space to store a full
-message, it will be truncated. If there are no messages available the method
-will block until the request can be satisfied.
+Receive a message. If there are no messages available the method will block
+until the request can be satisfied unless the C<ZMQ_DONTWAIT> flag is specified.
+If a message is not available and C<ZMQ_DONTWAIT> has been specified, this
+method will return C<undef> immediately.
 
 =head2 recvmsg( $flags = 0)
 
